# coding: utf-8

"""
    Marketing Events

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from hubspot.marketing.events.api_client import ApiClient
from hubspot.marketing.events.exceptions import ApiTypeError, ApiValueError  # noqa: F401


class BasicApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def archive(self, external_event_id, external_account_id, **kwargs):  # noqa: E501
        """Delete Marketing Event by External Ids  # noqa: E501

        Deletes the existing Marketing Event with the specified externalAccountId, externalEventId, if it exists.  Only Marketing Events created by the same app can be deleted.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.archive(external_event_id, external_account_id, async_req=True)
        >>> result = thread.get()

        :param external_event_id: The id of the marketing event in the external event application (required)
        :type external_event_id: str
        :param external_account_id: The accountId that is associated with this marketing event in the external event application (required)
        :type external_account_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """
        kwargs["_return_http_data_only"] = True
        return self.archive_with_http_info(external_event_id, external_account_id, **kwargs)  # noqa: E501

    def archive_with_http_info(self, external_event_id, external_account_id, **kwargs):  # noqa: E501
        """Delete Marketing Event by External Ids  # noqa: E501

        Deletes the existing Marketing Event with the specified externalAccountId, externalEventId, if it exists.  Only Marketing Events created by the same app can be deleted.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.archive_with_http_info(external_event_id, external_account_id, async_req=True)
        >>> result = thread.get()

        :param external_event_id: The id of the marketing event in the external event application (required)
        :type external_event_id: str
        :param external_account_id: The accountId that is associated with this marketing event in the external event application (required)
        :type external_account_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """

        local_var_params = locals()

        all_params = ["external_event_id", "external_account_id"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method archive" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'external_event_id' is set
        if self.api_client.client_side_validation and local_var_params.get("external_event_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `external_event_id` when calling `archive`")  # noqa: E501
        # verify the required parameter 'external_account_id' is set
        if self.api_client.client_side_validation and local_var_params.get("external_account_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `external_account_id` when calling `archive`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "external_event_id" in local_var_params:
            path_params["externalEventId"] = local_var_params["external_event_id"]  # noqa: E501

        query_params = []
        if local_var_params.get("external_account_id") is not None:  # noqa: E501
            query_params.append(("externalAccountId", local_var_params["external_account_id"]))  # noqa: E501

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["*/*"])  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {}

        return self.api_client.call_api(
            "/marketing/v3/marketing-events/events/{externalEventId}",
            "DELETE",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def archive_by_object_id(self, object_id, **kwargs):  # noqa: E501
        """Delete Marketing Event by objectId  # noqa: E501

        Deletes the existing Marketing Event with the specified objectId, if it exists.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.archive_by_object_id(object_id, async_req=True)
        >>> result = thread.get()

        :param object_id: The internal ID of the marketing event in HubSpot (required)
        :type object_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """
        kwargs["_return_http_data_only"] = True
        return self.archive_by_object_id_with_http_info(object_id, **kwargs)  # noqa: E501

    def archive_by_object_id_with_http_info(self, object_id, **kwargs):  # noqa: E501
        """Delete Marketing Event by objectId  # noqa: E501

        Deletes the existing Marketing Event with the specified objectId, if it exists.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.archive_by_object_id_with_http_info(object_id, async_req=True)
        >>> result = thread.get()

        :param object_id: The internal ID of the marketing event in HubSpot (required)
        :type object_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """

        local_var_params = locals()

        all_params = ["object_id"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method archive_by_object_id" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'object_id' is set
        if self.api_client.client_side_validation and local_var_params.get("object_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `object_id` when calling `archive_by_object_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "object_id" in local_var_params:
            path_params["objectId"] = local_var_params["object_id"]  # noqa: E501

        query_params = []

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["*/*"])  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {}

        return self.api_client.call_api(
            "/marketing/v3/marketing-events/{objectId}",
            "DELETE",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def create(self, marketing_event_create_request_params, **kwargs):  # noqa: E501
        """Create a marketing event  # noqa: E501

        Creates a new marketing event in HubSpot  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create(marketing_event_create_request_params, async_req=True)
        >>> result = thread.get()

        :param marketing_event_create_request_params: (required)
        :type marketing_event_create_request_params: MarketingEventCreateRequestParams
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: MarketingEventDefaultResponse
        """
        kwargs["_return_http_data_only"] = True
        return self.create_with_http_info(marketing_event_create_request_params, **kwargs)  # noqa: E501

    def create_with_http_info(self, marketing_event_create_request_params, **kwargs):  # noqa: E501
        """Create a marketing event  # noqa: E501

        Creates a new marketing event in HubSpot  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_with_http_info(marketing_event_create_request_params, async_req=True)
        >>> result = thread.get()

        :param marketing_event_create_request_params: (required)
        :type marketing_event_create_request_params: MarketingEventCreateRequestParams
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(MarketingEventDefaultResponse, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["marketing_event_create_request_params"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method create" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'marketing_event_create_request_params' is set
        if self.api_client.client_side_validation and local_var_params.get("marketing_event_create_request_params") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `marketing_event_create_request_params` when calling `create`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        if "marketing_event_create_request_params" in local_var_params:
            body_params = local_var_params["marketing_event_create_request_params"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # HTTP header `Content-Type`
        content_types_list = local_var_params.get("_content_type", self.api_client.select_header_content_type(["application/json"], "POST", body_params))  # noqa: E501
        if content_types_list:
            header_params["Content-Type"] = content_types_list

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {
            200: "MarketingEventDefaultResponse",
        }

        return self.api_client.call_api(
            "/marketing/v3/marketing-events/events",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def get_all(self, **kwargs):  # noqa: E501
        """Get all marketing event  # noqa: E501

        Returns all Marketing Events available on the portal, along with their properties, regardless of whether they were created manually or through the application.  The marketing events returned by this endpoint are sorted by objectId.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_all(async_req=True)
        >>> result = thread.get()

        :param after: The cursor indicating the position of the last retrieved item.
        :type after: str
        :param limit: The limit for response size. The default value is 10, the max number is 100
        :type limit: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: CollectionResponseMarketingEventPublicReadResponseV2ForwardPaging
        """
        kwargs["_return_http_data_only"] = True
        return self.get_all_with_http_info(**kwargs)  # noqa: E501

    def get_all_with_http_info(self, **kwargs):  # noqa: E501
        """Get all marketing event  # noqa: E501

        Returns all Marketing Events available on the portal, along with their properties, regardless of whether they were created manually or through the application.  The marketing events returned by this endpoint are sorted by objectId.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_all_with_http_info(async_req=True)
        >>> result = thread.get()

        :param after: The cursor indicating the position of the last retrieved item.
        :type after: str
        :param limit: The limit for response size. The default value is 10, the max number is 100
        :type limit: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(CollectionResponseMarketingEventPublicReadResponseV2ForwardPaging, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["after", "limit"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method get_all" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []
        if local_var_params.get("after") is not None:  # noqa: E501
            query_params.append(("after", local_var_params["after"]))  # noqa: E501
        if local_var_params.get("limit") is not None:  # noqa: E501
            query_params.append(("limit", local_var_params["limit"]))  # noqa: E501

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {
            200: "CollectionResponseMarketingEventPublicReadResponseV2ForwardPaging",
        }

        return self.api_client.call_api(
            "/marketing/v3/marketing-events/",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def get_by_object_id(self, object_id, **kwargs):  # noqa: E501
        """Get Marketing Event by objectId  # noqa: E501

        Returns the details of a Marketing Event with the specified objectId, if it exists.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_by_object_id(object_id, async_req=True)
        >>> result = thread.get()

        :param object_id: The internal ID of the marketing event in HubSpot (required)
        :type object_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: MarketingEventPublicReadResponseV2
        """
        kwargs["_return_http_data_only"] = True
        return self.get_by_object_id_with_http_info(object_id, **kwargs)  # noqa: E501

    def get_by_object_id_with_http_info(self, object_id, **kwargs):  # noqa: E501
        """Get Marketing Event by objectId  # noqa: E501

        Returns the details of a Marketing Event with the specified objectId, if it exists.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_by_object_id_with_http_info(object_id, async_req=True)
        >>> result = thread.get()

        :param object_id: The internal ID of the marketing event in HubSpot (required)
        :type object_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(MarketingEventPublicReadResponseV2, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["object_id"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method get_by_object_id" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'object_id' is set
        if self.api_client.client_side_validation and local_var_params.get("object_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `object_id` when calling `get_by_object_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "object_id" in local_var_params:
            path_params["objectId"] = local_var_params["object_id"]  # noqa: E501

        query_params = []

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {
            200: "MarketingEventPublicReadResponseV2",
        }

        return self.api_client.call_api(
            "/marketing/v3/marketing-events/{objectId}",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def get_details(self, external_event_id, external_account_id, **kwargs):  # noqa: E501
        """Get Marketing Event by External IDs  # noqa: E501

        Returns the details of a Marketing Event with the specified externalAccountId, externalEventId, if it exists.  Only Marketing Events created by the same app making the request can be retrieved.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_details(external_event_id, external_account_id, async_req=True)
        >>> result = thread.get()

        :param external_event_id: The id of the marketing event in the external event application (required)
        :type external_event_id: str
        :param external_account_id: The accountId that is associated with this marketing event in the external event application (required)
        :type external_account_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: MarketingEventPublicReadResponse
        """
        kwargs["_return_http_data_only"] = True
        return self.get_details_with_http_info(external_event_id, external_account_id, **kwargs)  # noqa: E501

    def get_details_with_http_info(self, external_event_id, external_account_id, **kwargs):  # noqa: E501
        """Get Marketing Event by External IDs  # noqa: E501

        Returns the details of a Marketing Event with the specified externalAccountId, externalEventId, if it exists.  Only Marketing Events created by the same app making the request can be retrieved.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_details_with_http_info(external_event_id, external_account_id, async_req=True)
        >>> result = thread.get()

        :param external_event_id: The id of the marketing event in the external event application (required)
        :type external_event_id: str
        :param external_account_id: The accountId that is associated with this marketing event in the external event application (required)
        :type external_account_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(MarketingEventPublicReadResponse, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["external_event_id", "external_account_id"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method get_details" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'external_event_id' is set
        if self.api_client.client_side_validation and local_var_params.get("external_event_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `external_event_id` when calling `get_details`")  # noqa: E501
        # verify the required parameter 'external_account_id' is set
        if self.api_client.client_side_validation and local_var_params.get("external_account_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `external_account_id` when calling `get_details`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "external_event_id" in local_var_params:
            path_params["externalEventId"] = local_var_params["external_event_id"]  # noqa: E501

        query_params = []
        if local_var_params.get("external_account_id") is not None:  # noqa: E501
            query_params.append(("externalAccountId", local_var_params["external_account_id"]))  # noqa: E501

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {
            200: "MarketingEventPublicReadResponse",
        }

        return self.api_client.call_api(
            "/marketing/v3/marketing-events/events/{externalEventId}",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def update(self, external_event_id, external_account_id, marketing_event_update_request_params, **kwargs):  # noqa: E501
        """Update Marketing Event by External IDs  # noqa: E501

        Updates the details of an existing Marketing Event identified by its externalAccountId, externalEventId if it exists.  Only Marketing Events created by the same app can be updated.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update(external_event_id, external_account_id, marketing_event_update_request_params, async_req=True)
        >>> result = thread.get()

        :param external_event_id: The id of the marketing event in the external event application (required)
        :type external_event_id: str
        :param external_account_id: The accountId that is associated with this marketing event in the external event application (required)
        :type external_account_id: str
        :param marketing_event_update_request_params: (required)
        :type marketing_event_update_request_params: MarketingEventUpdateRequestParams
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: MarketingEventPublicDefaultResponse
        """
        kwargs["_return_http_data_only"] = True
        return self.update_with_http_info(external_event_id, external_account_id, marketing_event_update_request_params, **kwargs)  # noqa: E501

    def update_with_http_info(self, external_event_id, external_account_id, marketing_event_update_request_params, **kwargs):  # noqa: E501
        """Update Marketing Event by External IDs  # noqa: E501

        Updates the details of an existing Marketing Event identified by its externalAccountId, externalEventId if it exists.  Only Marketing Events created by the same app can be updated.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update_with_http_info(external_event_id, external_account_id, marketing_event_update_request_params, async_req=True)
        >>> result = thread.get()

        :param external_event_id: The id of the marketing event in the external event application (required)
        :type external_event_id: str
        :param external_account_id: The accountId that is associated with this marketing event in the external event application (required)
        :type external_account_id: str
        :param marketing_event_update_request_params: (required)
        :type marketing_event_update_request_params: MarketingEventUpdateRequestParams
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(MarketingEventPublicDefaultResponse, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["external_event_id", "external_account_id", "marketing_event_update_request_params"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method update" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'external_event_id' is set
        if self.api_client.client_side_validation and local_var_params.get("external_event_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `external_event_id` when calling `update`")  # noqa: E501
        # verify the required parameter 'external_account_id' is set
        if self.api_client.client_side_validation and local_var_params.get("external_account_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `external_account_id` when calling `update`")  # noqa: E501
        # verify the required parameter 'marketing_event_update_request_params' is set
        if self.api_client.client_side_validation and local_var_params.get("marketing_event_update_request_params") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `marketing_event_update_request_params` when calling `update`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "external_event_id" in local_var_params:
            path_params["externalEventId"] = local_var_params["external_event_id"]  # noqa: E501

        query_params = []
        if local_var_params.get("external_account_id") is not None:  # noqa: E501
            query_params.append(("externalAccountId", local_var_params["external_account_id"]))  # noqa: E501

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        if "marketing_event_update_request_params" in local_var_params:
            body_params = local_var_params["marketing_event_update_request_params"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # HTTP header `Content-Type`
        content_types_list = local_var_params.get("_content_type", self.api_client.select_header_content_type(["application/json"], "PATCH", body_params))  # noqa: E501
        if content_types_list:
            header_params["Content-Type"] = content_types_list

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {
            200: "MarketingEventPublicDefaultResponse",
        }

        return self.api_client.call_api(
            "/marketing/v3/marketing-events/events/{externalEventId}",
            "PATCH",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def update_by_object_id(self, object_id, marketing_event_public_update_request_v2, **kwargs):  # noqa: E501
        """Update Marketing Event by objectId  # noqa: E501

        Updates the details of an existing Marketing Event identified by its objectId, if it exists.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update_by_object_id(object_id, marketing_event_public_update_request_v2, async_req=True)
        >>> result = thread.get()

        :param object_id: The internal ID of the marketing event in HubSpot (required)
        :type object_id: str
        :param marketing_event_public_update_request_v2: (required)
        :type marketing_event_public_update_request_v2: MarketingEventPublicUpdateRequestV2
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: MarketingEventPublicDefaultResponseV2
        """
        kwargs["_return_http_data_only"] = True
        return self.update_by_object_id_with_http_info(object_id, marketing_event_public_update_request_v2, **kwargs)  # noqa: E501

    def update_by_object_id_with_http_info(self, object_id, marketing_event_public_update_request_v2, **kwargs):  # noqa: E501
        """Update Marketing Event by objectId  # noqa: E501

        Updates the details of an existing Marketing Event identified by its objectId, if it exists.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update_by_object_id_with_http_info(object_id, marketing_event_public_update_request_v2, async_req=True)
        >>> result = thread.get()

        :param object_id: The internal ID of the marketing event in HubSpot (required)
        :type object_id: str
        :param marketing_event_public_update_request_v2: (required)
        :type marketing_event_public_update_request_v2: MarketingEventPublicUpdateRequestV2
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(MarketingEventPublicDefaultResponseV2, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["object_id", "marketing_event_public_update_request_v2"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method update_by_object_id" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'object_id' is set
        if self.api_client.client_side_validation and local_var_params.get("object_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `object_id` when calling `update_by_object_id`")  # noqa: E501
        # verify the required parameter 'marketing_event_public_update_request_v2' is set
        if self.api_client.client_side_validation and local_var_params.get("marketing_event_public_update_request_v2") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `marketing_event_public_update_request_v2` when calling `update_by_object_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "object_id" in local_var_params:
            path_params["objectId"] = local_var_params["object_id"]  # noqa: E501

        query_params = []

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        if "marketing_event_public_update_request_v2" in local_var_params:
            body_params = local_var_params["marketing_event_public_update_request_v2"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # HTTP header `Content-Type`
        content_types_list = local_var_params.get("_content_type", self.api_client.select_header_content_type(["application/json"], "PATCH", body_params))  # noqa: E501
        if content_types_list:
            header_params["Content-Type"] = content_types_list

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {
            200: "MarketingEventPublicDefaultResponseV2",
        }

        return self.api_client.call_api(
            "/marketing/v3/marketing-events/{objectId}",
            "PATCH",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def upsert(self, external_event_id, marketing_event_create_request_params, **kwargs):  # noqa: E501
        """Create or update a marketing event  # noqa: E501

        Upserts a marketing event If there is an existing marketing event with the specified ID, it will be updated; otherwise a new event will be created.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.upsert(external_event_id, marketing_event_create_request_params, async_req=True)
        >>> result = thread.get()

        :param external_event_id: The id of the marketing event in the external event application (required)
        :type external_event_id: str
        :param marketing_event_create_request_params: (required)
        :type marketing_event_create_request_params: MarketingEventCreateRequestParams
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: MarketingEventPublicDefaultResponse
        """
        kwargs["_return_http_data_only"] = True
        return self.upsert_with_http_info(external_event_id, marketing_event_create_request_params, **kwargs)  # noqa: E501

    def upsert_with_http_info(self, external_event_id, marketing_event_create_request_params, **kwargs):  # noqa: E501
        """Create or update a marketing event  # noqa: E501

        Upserts a marketing event If there is an existing marketing event with the specified ID, it will be updated; otherwise a new event will be created.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.upsert_with_http_info(external_event_id, marketing_event_create_request_params, async_req=True)
        >>> result = thread.get()

        :param external_event_id: The id of the marketing event in the external event application (required)
        :type external_event_id: str
        :param marketing_event_create_request_params: (required)
        :type marketing_event_create_request_params: MarketingEventCreateRequestParams
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(MarketingEventPublicDefaultResponse, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["external_event_id", "marketing_event_create_request_params"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method upsert" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'external_event_id' is set
        if self.api_client.client_side_validation and local_var_params.get("external_event_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `external_event_id` when calling `upsert`")  # noqa: E501
        # verify the required parameter 'marketing_event_create_request_params' is set
        if self.api_client.client_side_validation and local_var_params.get("marketing_event_create_request_params") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `marketing_event_create_request_params` when calling `upsert`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "external_event_id" in local_var_params:
            path_params["externalEventId"] = local_var_params["external_event_id"]  # noqa: E501

        query_params = []

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        if "marketing_event_create_request_params" in local_var_params:
            body_params = local_var_params["marketing_event_create_request_params"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # HTTP header `Content-Type`
        content_types_list = local_var_params.get("_content_type", self.api_client.select_header_content_type(["application/json"], "PUT", body_params))  # noqa: E501
        if content_types_list:
            header_params["Content-Type"] = content_types_list

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {
            200: "MarketingEventPublicDefaultResponse",
        }

        return self.api_client.call_api(
            "/marketing/v3/marketing-events/events/{externalEventId}",
            "PUT",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )



# coding: utf-8

"""
    Lists

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.crm.lists.configuration import Configuration


class PublicQuarterReference(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"hour": "int", "month": "int", "millisecond": "int", "reference_type": "str", "day": "int", "minute": "int", "second": "int"}

    attribute_map = {"hour": "hour", "month": "month", "millisecond": "millisecond", "reference_type": "referenceType", "day": "day", "minute": "minute", "second": "second"}

    def __init__(self, hour=None, month=None, millisecond=None, reference_type="QUARTER", day=None, minute=None, second=None, local_vars_configuration=None):  # noqa: E501
        """PublicQuarterReference - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._hour = None
        self._month = None
        self._millisecond = None
        self._reference_type = None
        self._day = None
        self._minute = None
        self._second = None
        self.discriminator = None

        if hour is not None:
            self.hour = hour
        self.month = month
        if millisecond is not None:
            self.millisecond = millisecond
        self.reference_type = reference_type
        self.day = day
        if minute is not None:
            self.minute = minute
        if second is not None:
            self.second = second

    @property
    def hour(self):
        """Gets the hour of this PublicQuarterReference.  # noqa: E501


        :return: The hour of this PublicQuarterReference.  # noqa: E501
        :rtype: int
        """
        return self._hour

    @hour.setter
    def hour(self, hour):
        """Sets the hour of this PublicQuarterReference.


        :param hour: The hour of this PublicQuarterReference.  # noqa: E501
        :type hour: int
        """

        self._hour = hour

    @property
    def month(self):
        """Gets the month of this PublicQuarterReference.  # noqa: E501


        :return: The month of this PublicQuarterReference.  # noqa: E501
        :rtype: int
        """
        return self._month

    @month.setter
    def month(self, month):
        """Sets the month of this PublicQuarterReference.


        :param month: The month of this PublicQuarterReference.  # noqa: E501
        :type month: int
        """
        if self.local_vars_configuration.client_side_validation and month is None:  # noqa: E501
            raise ValueError("Invalid value for `month`, must not be `None`")  # noqa: E501

        self._month = month

    @property
    def millisecond(self):
        """Gets the millisecond of this PublicQuarterReference.  # noqa: E501


        :return: The millisecond of this PublicQuarterReference.  # noqa: E501
        :rtype: int
        """
        return self._millisecond

    @millisecond.setter
    def millisecond(self, millisecond):
        """Sets the millisecond of this PublicQuarterReference.


        :param millisecond: The millisecond of this PublicQuarterReference.  # noqa: E501
        :type millisecond: int
        """

        self._millisecond = millisecond

    @property
    def reference_type(self):
        """Gets the reference_type of this PublicQuarterReference.  # noqa: E501


        :return: The reference_type of this PublicQuarterReference.  # noqa: E501
        :rtype: str
        """
        return self._reference_type

    @reference_type.setter
    def reference_type(self, reference_type):
        """Sets the reference_type of this PublicQuarterReference.


        :param reference_type: The reference_type of this PublicQuarterReference.  # noqa: E501
        :type reference_type: str
        """
        if self.local_vars_configuration.client_side_validation and reference_type is None:  # noqa: E501
            raise ValueError("Invalid value for `reference_type`, must not be `None`")  # noqa: E501
        allowed_values = ["QUARTER"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and reference_type not in allowed_values:  # noqa: E501
            raise ValueError("Invalid value for `reference_type` ({0}), must be one of {1}".format(reference_type, allowed_values))  # noqa: E501

        self._reference_type = reference_type

    @property
    def day(self):
        """Gets the day of this PublicQuarterReference.  # noqa: E501


        :return: The day of this PublicQuarterReference.  # noqa: E501
        :rtype: int
        """
        return self._day

    @day.setter
    def day(self, day):
        """Sets the day of this PublicQuarterReference.


        :param day: The day of this PublicQuarterReference.  # noqa: E501
        :type day: int
        """
        if self.local_vars_configuration.client_side_validation and day is None:  # noqa: E501
            raise ValueError("Invalid value for `day`, must not be `None`")  # noqa: E501

        self._day = day

    @property
    def minute(self):
        """Gets the minute of this PublicQuarterReference.  # noqa: E501


        :return: The minute of this PublicQuarterReference.  # noqa: E501
        :rtype: int
        """
        return self._minute

    @minute.setter
    def minute(self, minute):
        """Sets the minute of this PublicQuarterReference.


        :param minute: The minute of this PublicQuarterReference.  # noqa: E501
        :type minute: int
        """

        self._minute = minute

    @property
    def second(self):
        """Gets the second of this PublicQuarterReference.  # noqa: E501


        :return: The second of this PublicQuarterReference.  # noqa: E501
        :rtype: int
        """
        return self._second

    @second.setter
    def second(self, second):
        """Sets the second of this PublicQuarterReference.


        :param second: The second of this PublicQuarterReference.  # noqa: E501
        :type second: int
        """

        self._second = second

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PublicQuarterReference):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PublicQuarterReference):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Lists

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.crm.lists.configuration import Configuration


class PublicFormSubmissionFilterCoalescingRefineBy(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "max_occurrences": "int",
        "type": "str",
        "min_occurrences": "int",
        "set_type": "str",
        "comparison": "str",
        "time_offset": "PublicTimeOffset",
        "upper_bound_offset": "PublicTimeOffset",
        "range_type": "str",
        "lower_bound_offset": "PublicTimeOffset",
        "timestamp": "int",
        "upper_timestamp": "int",
        "lower_timestamp": "int",
        "endpoint_behavior": "str",
        "include_objects_with_no_value_set": "bool",
        "property_parser": "str",
        "operation_type": "str",
        "time_point": "PublicTimePointOperationTimePoint",
        "operator": "str",
        "upper_bound_endpoint_behavior": "str",
        "upper_bound_time_point": "PublicTimePointOperationTimePoint",
        "lower_bound_endpoint_behavior": "str",
        "lower_bound_time_point": "PublicTimePointOperationTimePoint",
    }

    attribute_map = {
        "max_occurrences": "maxOccurrences",
        "type": "type",
        "min_occurrences": "minOccurrences",
        "set_type": "setType",
        "comparison": "comparison",
        "time_offset": "timeOffset",
        "upper_bound_offset": "upperBoundOffset",
        "range_type": "rangeType",
        "lower_bound_offset": "lowerBoundOffset",
        "timestamp": "timestamp",
        "upper_timestamp": "upperTimestamp",
        "lower_timestamp": "lowerTimestamp",
        "endpoint_behavior": "endpointBehavior",
        "include_objects_with_no_value_set": "includeObjectsWithNoValueSet",
        "property_parser": "propertyParser",
        "operation_type": "operationType",
        "time_point": "timePoint",
        "operator": "operator",
        "upper_bound_endpoint_behavior": "upperBoundEndpointBehavior",
        "upper_bound_time_point": "upperBoundTimePoint",
        "lower_bound_endpoint_behavior": "lowerBoundEndpointBehavior",
        "lower_bound_time_point": "lowerBoundTimePoint",
    }

    def __init__(
        self,
        max_occurrences=None,
        type="TIME_RANGED",
        min_occurrences=None,
        set_type=None,
        comparison=None,
        time_offset=None,
        upper_bound_offset=None,
        range_type=None,
        lower_bound_offset=None,
        timestamp=None,
        upper_timestamp=None,
        lower_timestamp=None,
        endpoint_behavior=None,
        include_objects_with_no_value_set=None,
        property_parser=None,
        operation_type=None,
        time_point=None,
        operator=None,
        upper_bound_endpoint_behavior=None,
        upper_bound_time_point=None,
        lower_bound_endpoint_behavior=None,
        lower_bound_time_point=None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """PublicFormSubmissionFilterCoalescingRefineBy - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._max_occurrences = None
        self._type = None
        self._min_occurrences = None
        self._set_type = None
        self._comparison = None
        self._time_offset = None
        self._upper_bound_offset = None
        self._range_type = None
        self._lower_bound_offset = None
        self._timestamp = None
        self._upper_timestamp = None
        self._lower_timestamp = None
        self._endpoint_behavior = None
        self._include_objects_with_no_value_set = None
        self._property_parser = None
        self._operation_type = None
        self._time_point = None
        self._operator = None
        self._upper_bound_endpoint_behavior = None
        self._upper_bound_time_point = None
        self._lower_bound_endpoint_behavior = None
        self._lower_bound_time_point = None
        self.discriminator = None

        if max_occurrences is not None:
            self.max_occurrences = max_occurrences
        self.type = type
        if min_occurrences is not None:
            self.min_occurrences = min_occurrences
        self.set_type = set_type
        self.comparison = comparison
        self.time_offset = time_offset
        self.upper_bound_offset = upper_bound_offset
        self.range_type = range_type
        self.lower_bound_offset = lower_bound_offset
        self.timestamp = timestamp
        self.upper_timestamp = upper_timestamp
        self.lower_timestamp = lower_timestamp
        if endpoint_behavior is not None:
            self.endpoint_behavior = endpoint_behavior
        self.include_objects_with_no_value_set = include_objects_with_no_value_set
        if property_parser is not None:
            self.property_parser = property_parser
        self.operation_type = operation_type
        self.time_point = time_point
        self.operator = operator
        if upper_bound_endpoint_behavior is not None:
            self.upper_bound_endpoint_behavior = upper_bound_endpoint_behavior
        self.upper_bound_time_point = upper_bound_time_point
        if lower_bound_endpoint_behavior is not None:
            self.lower_bound_endpoint_behavior = lower_bound_endpoint_behavior
        self.lower_bound_time_point = lower_bound_time_point

    @property
    def max_occurrences(self):
        """Gets the max_occurrences of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501


        :return: The max_occurrences of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501
        :rtype: int
        """
        return self._max_occurrences

    @max_occurrences.setter
    def max_occurrences(self, max_occurrences):
        """Sets the max_occurrences of this PublicFormSubmissionFilterCoalescingRefineBy.


        :param max_occurrences: The max_occurrences of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501
        :type max_occurrences: int
        """

        self._max_occurrences = max_occurrences

    @property
    def type(self):
        """Gets the type of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501


        :return: The type of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this PublicFormSubmissionFilterCoalescingRefineBy.


        :param type: The type of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501
        :type type: str
        """
        if self.local_vars_configuration.client_side_validation and type is None:  # noqa: E501
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501
        allowed_values = ["TIME_RANGED"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and type not in allowed_values:  # noqa: E501
            raise ValueError("Invalid value for `type` ({0}), must be one of {1}".format(type, allowed_values))  # noqa: E501

        self._type = type

    @property
    def min_occurrences(self):
        """Gets the min_occurrences of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501


        :return: The min_occurrences of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501
        :rtype: int
        """
        return self._min_occurrences

    @min_occurrences.setter
    def min_occurrences(self, min_occurrences):
        """Sets the min_occurrences of this PublicFormSubmissionFilterCoalescingRefineBy.


        :param min_occurrences: The min_occurrences of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501
        :type min_occurrences: int
        """

        self._min_occurrences = min_occurrences

    @property
    def set_type(self):
        """Gets the set_type of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501


        :return: The set_type of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501
        :rtype: str
        """
        return self._set_type

    @set_type.setter
    def set_type(self, set_type):
        """Sets the set_type of this PublicFormSubmissionFilterCoalescingRefineBy.


        :param set_type: The set_type of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501
        :type set_type: str
        """
        if self.local_vars_configuration.client_side_validation and set_type is None:  # noqa: E501
            raise ValueError("Invalid value for `set_type`, must not be `None`")  # noqa: E501

        self._set_type = set_type

    @property
    def comparison(self):
        """Gets the comparison of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501


        :return: The comparison of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501
        :rtype: str
        """
        return self._comparison

    @comparison.setter
    def comparison(self, comparison):
        """Sets the comparison of this PublicFormSubmissionFilterCoalescingRefineBy.


        :param comparison: The comparison of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501
        :type comparison: str
        """
        if self.local_vars_configuration.client_side_validation and comparison is None:  # noqa: E501
            raise ValueError("Invalid value for `comparison`, must not be `None`")  # noqa: E501

        self._comparison = comparison

    @property
    def time_offset(self):
        """Gets the time_offset of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501


        :return: The time_offset of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501
        :rtype: PublicTimeOffset
        """
        return self._time_offset

    @time_offset.setter
    def time_offset(self, time_offset):
        """Sets the time_offset of this PublicFormSubmissionFilterCoalescingRefineBy.


        :param time_offset: The time_offset of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501
        :type time_offset: PublicTimeOffset
        """
        if self.local_vars_configuration.client_side_validation and time_offset is None:  # noqa: E501
            raise ValueError("Invalid value for `time_offset`, must not be `None`")  # noqa: E501

        self._time_offset = time_offset

    @property
    def upper_bound_offset(self):
        """Gets the upper_bound_offset of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501


        :return: The upper_bound_offset of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501
        :rtype: PublicTimeOffset
        """
        return self._upper_bound_offset

    @upper_bound_offset.setter
    def upper_bound_offset(self, upper_bound_offset):
        """Sets the upper_bound_offset of this PublicFormSubmissionFilterCoalescingRefineBy.


        :param upper_bound_offset: The upper_bound_offset of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501
        :type upper_bound_offset: PublicTimeOffset
        """
        if self.local_vars_configuration.client_side_validation and upper_bound_offset is None:  # noqa: E501
            raise ValueError("Invalid value for `upper_bound_offset`, must not be `None`")  # noqa: E501

        self._upper_bound_offset = upper_bound_offset

    @property
    def range_type(self):
        """Gets the range_type of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501


        :return: The range_type of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501
        :rtype: str
        """
        return self._range_type

    @range_type.setter
    def range_type(self, range_type):
        """Sets the range_type of this PublicFormSubmissionFilterCoalescingRefineBy.


        :param range_type: The range_type of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501
        :type range_type: str
        """
        if self.local_vars_configuration.client_side_validation and range_type is None:  # noqa: E501
            raise ValueError("Invalid value for `range_type`, must not be `None`")  # noqa: E501

        self._range_type = range_type

    @property
    def lower_bound_offset(self):
        """Gets the lower_bound_offset of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501


        :return: The lower_bound_offset of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501
        :rtype: PublicTimeOffset
        """
        return self._lower_bound_offset

    @lower_bound_offset.setter
    def lower_bound_offset(self, lower_bound_offset):
        """Sets the lower_bound_offset of this PublicFormSubmissionFilterCoalescingRefineBy.


        :param lower_bound_offset: The lower_bound_offset of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501
        :type lower_bound_offset: PublicTimeOffset
        """
        if self.local_vars_configuration.client_side_validation and lower_bound_offset is None:  # noqa: E501
            raise ValueError("Invalid value for `lower_bound_offset`, must not be `None`")  # noqa: E501

        self._lower_bound_offset = lower_bound_offset

    @property
    def timestamp(self):
        """Gets the timestamp of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501


        :return: The timestamp of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501
        :rtype: int
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """Sets the timestamp of this PublicFormSubmissionFilterCoalescingRefineBy.


        :param timestamp: The timestamp of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501
        :type timestamp: int
        """
        if self.local_vars_configuration.client_side_validation and timestamp is None:  # noqa: E501
            raise ValueError("Invalid value for `timestamp`, must not be `None`")  # noqa: E501

        self._timestamp = timestamp

    @property
    def upper_timestamp(self):
        """Gets the upper_timestamp of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501


        :return: The upper_timestamp of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501
        :rtype: int
        """
        return self._upper_timestamp

    @upper_timestamp.setter
    def upper_timestamp(self, upper_timestamp):
        """Sets the upper_timestamp of this PublicFormSubmissionFilterCoalescingRefineBy.


        :param upper_timestamp: The upper_timestamp of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501
        :type upper_timestamp: int
        """
        if self.local_vars_configuration.client_side_validation and upper_timestamp is None:  # noqa: E501
            raise ValueError("Invalid value for `upper_timestamp`, must not be `None`")  # noqa: E501

        self._upper_timestamp = upper_timestamp

    @property
    def lower_timestamp(self):
        """Gets the lower_timestamp of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501


        :return: The lower_timestamp of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501
        :rtype: int
        """
        return self._lower_timestamp

    @lower_timestamp.setter
    def lower_timestamp(self, lower_timestamp):
        """Sets the lower_timestamp of this PublicFormSubmissionFilterCoalescingRefineBy.


        :param lower_timestamp: The lower_timestamp of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501
        :type lower_timestamp: int
        """
        if self.local_vars_configuration.client_side_validation and lower_timestamp is None:  # noqa: E501
            raise ValueError("Invalid value for `lower_timestamp`, must not be `None`")  # noqa: E501

        self._lower_timestamp = lower_timestamp

    @property
    def endpoint_behavior(self):
        """Gets the endpoint_behavior of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501


        :return: The endpoint_behavior of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501
        :rtype: str
        """
        return self._endpoint_behavior

    @endpoint_behavior.setter
    def endpoint_behavior(self, endpoint_behavior):
        """Sets the endpoint_behavior of this PublicFormSubmissionFilterCoalescingRefineBy.


        :param endpoint_behavior: The endpoint_behavior of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501
        :type endpoint_behavior: str
        """

        self._endpoint_behavior = endpoint_behavior

    @property
    def include_objects_with_no_value_set(self):
        """Gets the include_objects_with_no_value_set of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501


        :return: The include_objects_with_no_value_set of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501
        :rtype: bool
        """
        return self._include_objects_with_no_value_set

    @include_objects_with_no_value_set.setter
    def include_objects_with_no_value_set(self, include_objects_with_no_value_set):
        """Sets the include_objects_with_no_value_set of this PublicFormSubmissionFilterCoalescingRefineBy.


        :param include_objects_with_no_value_set: The include_objects_with_no_value_set of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501
        :type include_objects_with_no_value_set: bool
        """
        if self.local_vars_configuration.client_side_validation and include_objects_with_no_value_set is None:  # noqa: E501
            raise ValueError("Invalid value for `include_objects_with_no_value_set`, must not be `None`")  # noqa: E501

        self._include_objects_with_no_value_set = include_objects_with_no_value_set

    @property
    def property_parser(self):
        """Gets the property_parser of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501


        :return: The property_parser of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501
        :rtype: str
        """
        return self._property_parser

    @property_parser.setter
    def property_parser(self, property_parser):
        """Sets the property_parser of this PublicFormSubmissionFilterCoalescingRefineBy.


        :param property_parser: The property_parser of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501
        :type property_parser: str
        """

        self._property_parser = property_parser

    @property
    def operation_type(self):
        """Gets the operation_type of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501


        :return: The operation_type of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501
        :rtype: str
        """
        return self._operation_type

    @operation_type.setter
    def operation_type(self, operation_type):
        """Sets the operation_type of this PublicFormSubmissionFilterCoalescingRefineBy.


        :param operation_type: The operation_type of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501
        :type operation_type: str
        """
        if self.local_vars_configuration.client_side_validation and operation_type is None:  # noqa: E501
            raise ValueError("Invalid value for `operation_type`, must not be `None`")  # noqa: E501

        self._operation_type = operation_type

    @property
    def time_point(self):
        """Gets the time_point of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501


        :return: The time_point of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501
        :rtype: PublicTimePointOperationTimePoint
        """
        return self._time_point

    @time_point.setter
    def time_point(self, time_point):
        """Sets the time_point of this PublicFormSubmissionFilterCoalescingRefineBy.


        :param time_point: The time_point of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501
        :type time_point: PublicTimePointOperationTimePoint
        """
        if self.local_vars_configuration.client_side_validation and time_point is None:  # noqa: E501
            raise ValueError("Invalid value for `time_point`, must not be `None`")  # noqa: E501

        self._time_point = time_point

    @property
    def operator(self):
        """Gets the operator of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501


        :return: The operator of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501
        :rtype: str
        """
        return self._operator

    @operator.setter
    def operator(self, operator):
        """Sets the operator of this PublicFormSubmissionFilterCoalescingRefineBy.


        :param operator: The operator of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501
        :type operator: str
        """
        if self.local_vars_configuration.client_side_validation and operator is None:  # noqa: E501
            raise ValueError("Invalid value for `operator`, must not be `None`")  # noqa: E501

        self._operator = operator

    @property
    def upper_bound_endpoint_behavior(self):
        """Gets the upper_bound_endpoint_behavior of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501


        :return: The upper_bound_endpoint_behavior of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501
        :rtype: str
        """
        return self._upper_bound_endpoint_behavior

    @upper_bound_endpoint_behavior.setter
    def upper_bound_endpoint_behavior(self, upper_bound_endpoint_behavior):
        """Sets the upper_bound_endpoint_behavior of this PublicFormSubmissionFilterCoalescingRefineBy.


        :param upper_bound_endpoint_behavior: The upper_bound_endpoint_behavior of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501
        :type upper_bound_endpoint_behavior: str
        """

        self._upper_bound_endpoint_behavior = upper_bound_endpoint_behavior

    @property
    def upper_bound_time_point(self):
        """Gets the upper_bound_time_point of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501


        :return: The upper_bound_time_point of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501
        :rtype: PublicTimePointOperationTimePoint
        """
        return self._upper_bound_time_point

    @upper_bound_time_point.setter
    def upper_bound_time_point(self, upper_bound_time_point):
        """Sets the upper_bound_time_point of this PublicFormSubmissionFilterCoalescingRefineBy.


        :param upper_bound_time_point: The upper_bound_time_point of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501
        :type upper_bound_time_point: PublicTimePointOperationTimePoint
        """
        if self.local_vars_configuration.client_side_validation and upper_bound_time_point is None:  # noqa: E501
            raise ValueError("Invalid value for `upper_bound_time_point`, must not be `None`")  # noqa: E501

        self._upper_bound_time_point = upper_bound_time_point

    @property
    def lower_bound_endpoint_behavior(self):
        """Gets the lower_bound_endpoint_behavior of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501


        :return: The lower_bound_endpoint_behavior of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501
        :rtype: str
        """
        return self._lower_bound_endpoint_behavior

    @lower_bound_endpoint_behavior.setter
    def lower_bound_endpoint_behavior(self, lower_bound_endpoint_behavior):
        """Sets the lower_bound_endpoint_behavior of this PublicFormSubmissionFilterCoalescingRefineBy.


        :param lower_bound_endpoint_behavior: The lower_bound_endpoint_behavior of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501
        :type lower_bound_endpoint_behavior: str
        """

        self._lower_bound_endpoint_behavior = lower_bound_endpoint_behavior

    @property
    def lower_bound_time_point(self):
        """Gets the lower_bound_time_point of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501


        :return: The lower_bound_time_point of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501
        :rtype: PublicTimePointOperationTimePoint
        """
        return self._lower_bound_time_point

    @lower_bound_time_point.setter
    def lower_bound_time_point(self, lower_bound_time_point):
        """Sets the lower_bound_time_point of this PublicFormSubmissionFilterCoalescingRefineBy.


        :param lower_bound_time_point: The lower_bound_time_point of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501
        :type lower_bound_time_point: PublicTimePointOperationTimePoint
        """
        if self.local_vars_configuration.client_side_validation and lower_bound_time_point is None:  # noqa: E501
            raise ValueError("Invalid value for `lower_bound_time_point`, must not be `None`")  # noqa: E501

        self._lower_bound_time_point = lower_bound_time_point

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PublicFormSubmissionFilterCoalescingRefineBy):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PublicFormSubmissionFilterCoalescingRefineBy):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# flake8: noqa
"""
    Public App Crm Cards

    Allows an app to extend the CRM UI by surfacing custom cards in the sidebar of record pages. These cards are defined up-front as part of app configuration, then populated by external data fetch requests when the record page is accessed by a user.  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from hubspot.crm.extensions.cards.models.action_confirmation_body import ActionConfirmationBody
from hubspot.crm.extensions.cards.models.action_hook_action_body import ActionHookActionBody
from hubspot.crm.extensions.cards.models.card_actions import CardActions
from hubspot.crm.extensions.cards.models.card_audit_response import CardAuditResponse
from hubspot.crm.extensions.cards.models.card_create_request import CardCreateRequest
from hubspot.crm.extensions.cards.models.card_display_body import CardDisplayBody
from hubspot.crm.extensions.cards.models.card_display_property import CardDisplayProperty
from hubspot.crm.extensions.cards.models.card_fetch_body import CardFetchBody
from hubspot.crm.extensions.cards.models.card_fetch_body_patch import CardFetchBodyPatch
from hubspot.crm.extensions.cards.models.card_object_type_body import CardObjectTypeBody
from hubspot.crm.extensions.cards.models.card_patch_request import CardPatchRequest
from hubspot.crm.extensions.cards.models.display_option import DisplayOption
from hubspot.crm.extensions.cards.models.error import Error
from hubspot.crm.extensions.cards.models.error_detail import ErrorDetail
from hubspot.crm.extensions.cards.models.i_frame_action_body import IFrameActionBody
from hubspot.crm.extensions.cards.models.integrator_card_payload_response import IntegratorCardPayloadResponse
from hubspot.crm.extensions.cards.models.integrator_object_result import IntegratorObjectResult
from hubspot.crm.extensions.cards.models.integrator_object_result_actions_inner import IntegratorObjectResultActionsInner
from hubspot.crm.extensions.cards.models.object_token import ObjectToken
from hubspot.crm.extensions.cards.models.public_card_fetch_body import PublicCardFetchBody
from hubspot.crm.extensions.cards.models.public_card_list_response import PublicCardListResponse
from hubspot.crm.extensions.cards.models.public_card_response import PublicCardResponse
from hubspot.crm.extensions.cards.models.top_level_actions import TopLevelActions



from ..discovery_base import DiscoveryBase


class Discovery(DiscoveryBase):
    @property
    def users(self):
        from .users.discovery import Discovery as UsersDiscovery
        return UsersDiscovery(self.config)

    @property
    def business_units(self):
        from .business_units.discovery import Discovery as BusinessUnitsDiscovery
        return BusinessUnitsDiscovery(self.config)



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from hubspot.marketing.emails.api.marketing_emails_api import MarketingEmailsApi
from hubspot.marketing.emails.api.statistics_api import StatisticsApi



# coding: utf-8

"""
    Schemas

    The CRM uses schemas to define how custom objects should store and represent information in the HubSpot CRM. Schemas define details about an object's type, properties, and associations. The schema can be uniquely identified by its **object type ID**.  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from hubspot.crm.schemas.api_client import ApiClient
from hubspot.crm.schemas.exceptions import ApiTypeError, ApiValueError  # noqa: F401


class CoreApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def archive(self, object_type, **kwargs):  # noqa: E501
        """Delete a schema  # noqa: E501

        Deletes a schema. Any existing records of this schema must be deleted **first**. Otherwise this call will fail.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.archive(object_type, async_req=True)
        >>> result = thread.get()

        :param object_type: Fully qualified name or object type ID of your schema. (required)
        :type object_type: str
        :param archived: Whether to return only results that have been archived.
        :type archived: bool
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """
        kwargs["_return_http_data_only"] = True
        return self.archive_with_http_info(object_type, **kwargs)  # noqa: E501

    def archive_with_http_info(self, object_type, **kwargs):  # noqa: E501
        """Delete a schema  # noqa: E501

        Deletes a schema. Any existing records of this schema must be deleted **first**. Otherwise this call will fail.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.archive_with_http_info(object_type, async_req=True)
        >>> result = thread.get()

        :param object_type: Fully qualified name or object type ID of your schema. (required)
        :type object_type: str
        :param archived: Whether to return only results that have been archived.
        :type archived: bool
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """

        local_var_params = locals()

        all_params = ["object_type", "archived"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method archive" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'object_type' is set
        if self.api_client.client_side_validation and local_var_params.get("object_type") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `object_type` when calling `archive`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "object_type" in local_var_params:
            path_params["objectType"] = local_var_params["object_type"]  # noqa: E501

        query_params = []
        if local_var_params.get("archived") is not None:  # noqa: E501
            query_params.append(("archived", local_var_params["archived"]))  # noqa: E501

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["*/*"])  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {}

        return self.api_client.call_api(
            "/crm-object-schemas/v3/schemas/{objectType}",
            "DELETE",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def archive_association(self, object_type, association_identifier, **kwargs):  # noqa: E501
        """Remove an association  # noqa: E501

        Removes an existing association from a schema.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.archive_association(object_type, association_identifier, async_req=True)
        >>> result = thread.get()

        :param object_type: Fully qualified name or object type ID of your schema. (required)
        :type object_type: str
        :param association_identifier: Unique ID of the association to remove. (required)
        :type association_identifier: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """
        kwargs["_return_http_data_only"] = True
        return self.archive_association_with_http_info(object_type, association_identifier, **kwargs)  # noqa: E501

    def archive_association_with_http_info(self, object_type, association_identifier, **kwargs):  # noqa: E501
        """Remove an association  # noqa: E501

        Removes an existing association from a schema.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.archive_association_with_http_info(object_type, association_identifier, async_req=True)
        >>> result = thread.get()

        :param object_type: Fully qualified name or object type ID of your schema. (required)
        :type object_type: str
        :param association_identifier: Unique ID of the association to remove. (required)
        :type association_identifier: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """

        local_var_params = locals()

        all_params = ["object_type", "association_identifier"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method archive_association" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'object_type' is set
        if self.api_client.client_side_validation and local_var_params.get("object_type") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `object_type` when calling `archive_association`")  # noqa: E501
        # verify the required parameter 'association_identifier' is set
        if self.api_client.client_side_validation and local_var_params.get("association_identifier") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `association_identifier` when calling `archive_association`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "object_type" in local_var_params:
            path_params["objectType"] = local_var_params["object_type"]  # noqa: E501
        if "association_identifier" in local_var_params:
            path_params["associationIdentifier"] = local_var_params["association_identifier"]  # noqa: E501

        query_params = []

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["*/*"])  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {}

        return self.api_client.call_api(
            "/crm-object-schemas/v3/schemas/{objectType}/associations/{associationIdentifier}",
            "DELETE",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def create(self, object_schema_egg, **kwargs):  # noqa: E501
        """Create a new schema  # noqa: E501

        Define a new object schema, along with custom properties and associations. The entire object schema, including its object type ID, properties, and associations will be returned in the response.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create(object_schema_egg, async_req=True)
        >>> result = thread.get()

        :param object_schema_egg: Object schema definition, including properties and associations. (required)
        :type object_schema_egg: ObjectSchemaEgg
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ObjectSchema
        """
        kwargs["_return_http_data_only"] = True
        return self.create_with_http_info(object_schema_egg, **kwargs)  # noqa: E501

    def create_with_http_info(self, object_schema_egg, **kwargs):  # noqa: E501
        """Create a new schema  # noqa: E501

        Define a new object schema, along with custom properties and associations. The entire object schema, including its object type ID, properties, and associations will be returned in the response.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_with_http_info(object_schema_egg, async_req=True)
        >>> result = thread.get()

        :param object_schema_egg: Object schema definition, including properties and associations. (required)
        :type object_schema_egg: ObjectSchemaEgg
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(ObjectSchema, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["object_schema_egg"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method create" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'object_schema_egg' is set
        if self.api_client.client_side_validation and local_var_params.get("object_schema_egg") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `object_schema_egg` when calling `create`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        if "object_schema_egg" in local_var_params:
            body_params = local_var_params["object_schema_egg"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # HTTP header `Content-Type`
        content_types_list = local_var_params.get("_content_type", self.api_client.select_header_content_type(["application/json"], "POST", body_params))  # noqa: E501
        if content_types_list:
            header_params["Content-Type"] = content_types_list

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {
            201: "ObjectSchema",
        }

        return self.api_client.call_api(
            "/crm-object-schemas/v3/schemas",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def create_association(self, object_type, association_definition_egg, **kwargs):  # noqa: E501
        """Create an association  # noqa: E501

        Defines a new association between the primary schema's object type and other object types.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_association(object_type, association_definition_egg, async_req=True)
        >>> result = thread.get()

        :param object_type: Fully qualified name or object type ID of your schema. (required)
        :type object_type: str
        :param association_definition_egg: Attributes that define the association. (required)
        :type association_definition_egg: AssociationDefinitionEgg
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: AssociationDefinition
        """
        kwargs["_return_http_data_only"] = True
        return self.create_association_with_http_info(object_type, association_definition_egg, **kwargs)  # noqa: E501

    def create_association_with_http_info(self, object_type, association_definition_egg, **kwargs):  # noqa: E501
        """Create an association  # noqa: E501

        Defines a new association between the primary schema's object type and other object types.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_association_with_http_info(object_type, association_definition_egg, async_req=True)
        >>> result = thread.get()

        :param object_type: Fully qualified name or object type ID of your schema. (required)
        :type object_type: str
        :param association_definition_egg: Attributes that define the association. (required)
        :type association_definition_egg: AssociationDefinitionEgg
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(AssociationDefinition, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["object_type", "association_definition_egg"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method create_association" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'object_type' is set
        if self.api_client.client_side_validation and local_var_params.get("object_type") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `object_type` when calling `create_association`")  # noqa: E501
        # verify the required parameter 'association_definition_egg' is set
        if self.api_client.client_side_validation and local_var_params.get("association_definition_egg") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `association_definition_egg` when calling `create_association`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "object_type" in local_var_params:
            path_params["objectType"] = local_var_params["object_type"]  # noqa: E501

        query_params = []

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        if "association_definition_egg" in local_var_params:
            body_params = local_var_params["association_definition_egg"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # HTTP header `Content-Type`
        content_types_list = local_var_params.get("_content_type", self.api_client.select_header_content_type(["application/json"], "POST", body_params))  # noqa: E501
        if content_types_list:
            header_params["Content-Type"] = content_types_list

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {
            201: "AssociationDefinition",
        }

        return self.api_client.call_api(
            "/crm-object-schemas/v3/schemas/{objectType}/associations",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def get_all(self, **kwargs):  # noqa: E501
        """Get all schemas  # noqa: E501

        Returns all object schemas that have been defined for your account.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_all(async_req=True)
        >>> result = thread.get()

        :param archived: Whether to return only results that have been archived.
        :type archived: bool
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: CollectionResponseObjectSchemaNoPaging
        """
        kwargs["_return_http_data_only"] = True
        return self.get_all_with_http_info(**kwargs)  # noqa: E501

    def get_all_with_http_info(self, **kwargs):  # noqa: E501
        """Get all schemas  # noqa: E501

        Returns all object schemas that have been defined for your account.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_all_with_http_info(async_req=True)
        >>> result = thread.get()

        :param archived: Whether to return only results that have been archived.
        :type archived: bool
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(CollectionResponseObjectSchemaNoPaging, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["archived"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method get_all" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []
        if local_var_params.get("archived") is not None:  # noqa: E501
            query_params.append(("archived", local_var_params["archived"]))  # noqa: E501

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {
            200: "CollectionResponseObjectSchemaNoPaging",
        }

        return self.api_client.call_api(
            "/crm-object-schemas/v3/schemas",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def get_by_id(self, object_type, **kwargs):  # noqa: E501
        """Get an existing schema  # noqa: E501

        Returns an existing object schema.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_by_id(object_type, async_req=True)
        >>> result = thread.get()

        :param object_type: Fully qualified name or object type ID of your schema. (required)
        :type object_type: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ObjectSchema
        """
        kwargs["_return_http_data_only"] = True
        return self.get_by_id_with_http_info(object_type, **kwargs)  # noqa: E501

    def get_by_id_with_http_info(self, object_type, **kwargs):  # noqa: E501
        """Get an existing schema  # noqa: E501

        Returns an existing object schema.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_by_id_with_http_info(object_type, async_req=True)
        >>> result = thread.get()

        :param object_type: Fully qualified name or object type ID of your schema. (required)
        :type object_type: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(ObjectSchema, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["object_type"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method get_by_id" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'object_type' is set
        if self.api_client.client_side_validation and local_var_params.get("object_type") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `object_type` when calling `get_by_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "object_type" in local_var_params:
            path_params["objectType"] = local_var_params["object_type"]  # noqa: E501

        query_params = []

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {
            200: "ObjectSchema",
        }

        return self.api_client.call_api(
            "/crm-object-schemas/v3/schemas/{objectType}",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def update(self, object_type, object_type_definition_patch, **kwargs):  # noqa: E501
        """Update a schema  # noqa: E501

        Update the details for an existing object schema.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update(object_type, object_type_definition_patch, async_req=True)
        >>> result = thread.get()

        :param object_type: Fully qualified name or object type ID of your schema. (required)
        :type object_type: str
        :param object_type_definition_patch: Attributes to update in your schema. (required)
        :type object_type_definition_patch: ObjectTypeDefinitionPatch
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ObjectTypeDefinition
        """
        kwargs["_return_http_data_only"] = True
        return self.update_with_http_info(object_type, object_type_definition_patch, **kwargs)  # noqa: E501

    def update_with_http_info(self, object_type, object_type_definition_patch, **kwargs):  # noqa: E501
        """Update a schema  # noqa: E501

        Update the details for an existing object schema.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update_with_http_info(object_type, object_type_definition_patch, async_req=True)
        >>> result = thread.get()

        :param object_type: Fully qualified name or object type ID of your schema. (required)
        :type object_type: str
        :param object_type_definition_patch: Attributes to update in your schema. (required)
        :type object_type_definition_patch: ObjectTypeDefinitionPatch
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(ObjectTypeDefinition, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["object_type", "object_type_definition_patch"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method update" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'object_type' is set
        if self.api_client.client_side_validation and local_var_params.get("object_type") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `object_type` when calling `update`")  # noqa: E501
        # verify the required parameter 'object_type_definition_patch' is set
        if self.api_client.client_side_validation and local_var_params.get("object_type_definition_patch") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `object_type_definition_patch` when calling `update`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "object_type" in local_var_params:
            path_params["objectType"] = local_var_params["object_type"]  # noqa: E501

        query_params = []

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        if "object_type_definition_patch" in local_var_params:
            body_params = local_var_params["object_type_definition_patch"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # HTTP header `Content-Type`
        content_types_list = local_var_params.get("_content_type", self.api_client.select_header_content_type(["application/json"], "PATCH", body_params))  # noqa: E501
        if content_types_list:
            header_params["Content-Type"] = content_types_list

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {
            200: "ObjectTypeDefinition",
        }

        return self.api_client.call_api(
            "/crm-object-schemas/v3/schemas/{objectType}",
            "PATCH",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )



import hubspot.webhooks as api_client
from ..discovery_base import DiscoveryBase


class Discovery(DiscoveryBase):
    @property
    def settings_api(self) -> api_client.SettingsApi:
        return self._configure_api_client(api_client, "SettingsApi")

    @property
    def subscriptions_api(self) -> api_client.SubscriptionsApi:
        return self._configure_api_client(api_client, "SubscriptionsApi")



import requests
import json
from urllib.parse import urlencode

from hubspot.utils.requests.http_auth import Auth


class Request:
    def __init__(self, config: dict, options: dict = None):
        self.base_url = config.get("base_url", "https://api.hubapi.com")
        self.headers = {}
        self.body = None
        self.default_json = options.get("default_json", True) if options else True
        self.options = options or {}
        self.method = self.options.get("method", "GET").upper()
        self.config = config

        self.init_headers()
        self.apply_auth()
        self.url = self.generate_url()
        self.set_body()

    def get_url(self) -> str:
        return self.url

    def get_method(self) -> str:
        return self.method

    def get_options_for_sending(self) -> dict:
        options = {}
        if self.headers:
            options["headers"] = self.headers
        if self.body:
            options["data"] = self.body
        return options

    def apply_auth(self):
        auth = Auth.choose_auth(self.config, self.options)

        if auth["auth_type"]:
            if auth["auth_type"] == "api_key":
                self.options["qs"] = self.options.get("qs", {})
                self.options["qs"]["hapikey"] = self.config.get(auth["auth_type"])

            if auth["auth_type"] == "access_token":
                self.headers["Authorization"] = f"Bearer {self.config.get(auth['auth_type'])}"

    def init_headers(self):
        if self.default_json:
            self.headers["Content-Type"] = "application/json"
        self.headers.update(self.get_default_headers())
        if "headers" in self.options:
            self.headers.update(self.options["headers"])

    def get_default_headers(self) -> dict:
        headers = {
            "User-Agent": self.config.get("user_agent", "custom-python-client/1.0")
        }
        if self.default_json:
            headers["Accept"] = "application/json, */*;q=0.8"
        return headers

    def generate_url(self) -> str:
        url = self.options.get("base_url", self.base_url)
        path = self.options.get("path", "")
        url = f"{url}{path}"

        qs = self.options.get("qs")
        if qs:
            query_string = urlencode(qs, doseq=True)
            delimiter = "&" if "?" in url else "?"
            url += f"{delimiter}{query_string}"

        return url

    def set_body(self):
        if "body" in self.options:
            self.body = self.options["body"]
            if self.default_json and isinstance(self.body, (dict, list)):
                self.body = json.dumps(self.body)

    def send(self) -> requests.Response:
        try:
            method_func = getattr(requests, self.method.lower(), requests.get)
            response = method_func(self.get_url(), **self.get_options_for_sending())
            return response
        except requests.exceptions.RequestException as e:
            print(f"HTTP error occurred: {e}")
            raise



import hubspot.settings.business_units as api_client
from ...discovery_base import DiscoveryBase


class Discovery(DiscoveryBase):
    @property
    def business_unit_api(self) -> api_client.BusinessUnitApi:
        return self._configure_api_client(api_client, "BusinessUnitApi")



# coding: utf-8

# flake8: noqa

"""
    Cms Content Audit

    Use this endpoint to query audit logs of CMS changes that occurred on your HubSpot account.  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "1.0.0"

# import apis into sdk package
from hubspot.cms.audit_logs.api.audit_logs_api import AuditLogsApi

# import ApiClient
from hubspot.cms.audit_logs.api_client import ApiClient
from hubspot.cms.audit_logs.configuration import Configuration
from hubspot.cms.audit_logs.exceptions import OpenApiException
from hubspot.cms.audit_logs.exceptions import ApiTypeError
from hubspot.cms.audit_logs.exceptions import ApiValueError
from hubspot.cms.audit_logs.exceptions import ApiKeyError
from hubspot.cms.audit_logs.exceptions import ApiAttributeError
from hubspot.cms.audit_logs.exceptions import ApiException

# import models into sdk package
from hubspot.cms.audit_logs.models.collection_response_public_audit_log import CollectionResponsePublicAuditLog
from hubspot.cms.audit_logs.models.error import Error
from hubspot.cms.audit_logs.models.error_detail import ErrorDetail
from hubspot.cms.audit_logs.models.next_page import NextPage
from hubspot.cms.audit_logs.models.paging import Paging
from hubspot.cms.audit_logs.models.previous_page import PreviousPage
from hubspot.cms.audit_logs.models.public_audit_log import PublicAuditLog



# coding: utf-8

"""
    Marketing Emails

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.marketing.emails.configuration import Configuration


class PublicEmailTestingDetails(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "ab_sampling_default": "str",
        "ab_sample_size_default": "str",
        "ab_status": "str",
        "ab_test_percentage": "int",
        "hours_to_wait": "int",
        "test_id": "str",
        "ab_success_metric": "str",
    }

    attribute_map = {
        "ab_sampling_default": "abSamplingDefault",
        "ab_sample_size_default": "abSampleSizeDefault",
        "ab_status": "abStatus",
        "ab_test_percentage": "abTestPercentage",
        "hours_to_wait": "hoursToWait",
        "test_id": "testId",
        "ab_success_metric": "abSuccessMetric",
    }

    def __init__(
        self, ab_sampling_default=None, ab_sample_size_default=None, ab_status=None, ab_test_percentage=None, hours_to_wait=None, test_id=None, ab_success_metric=None, local_vars_configuration=None
    ):  # noqa: E501
        """PublicEmailTestingDetails - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._ab_sampling_default = None
        self._ab_sample_size_default = None
        self._ab_status = None
        self._ab_test_percentage = None
        self._hours_to_wait = None
        self._test_id = None
        self._ab_success_metric = None
        self.discriminator = None

        if ab_sampling_default is not None:
            self.ab_sampling_default = ab_sampling_default
        if ab_sample_size_default is not None:
            self.ab_sample_size_default = ab_sample_size_default
        if ab_status is not None:
            self.ab_status = ab_status
        if ab_test_percentage is not None:
            self.ab_test_percentage = ab_test_percentage
        if hours_to_wait is not None:
            self.hours_to_wait = hours_to_wait
        if test_id is not None:
            self.test_id = test_id
        if ab_success_metric is not None:
            self.ab_success_metric = ab_success_metric

    @property
    def ab_sampling_default(self):
        """Gets the ab_sampling_default of this PublicEmailTestingDetails.  # noqa: E501

        Version of the email that should be sent if the results are inconclusive after the test period, master or variant.  # noqa: E501

        :return: The ab_sampling_default of this PublicEmailTestingDetails.  # noqa: E501
        :rtype: str
        """
        return self._ab_sampling_default

    @ab_sampling_default.setter
    def ab_sampling_default(self, ab_sampling_default):
        """Sets the ab_sampling_default of this PublicEmailTestingDetails.

        Version of the email that should be sent if the results are inconclusive after the test period, master or variant.  # noqa: E501

        :param ab_sampling_default: The ab_sampling_default of this PublicEmailTestingDetails.  # noqa: E501
        :type ab_sampling_default: str
        """
        allowed_values = ["master", "variant", "loser_variant", "mab_master", "mab_variant", "automated_master", "automated_variant", "automated_loser_variant"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and ab_sampling_default not in allowed_values:  # noqa: E501
            raise ValueError("Invalid value for `ab_sampling_default` ({0}), must be one of {1}".format(ab_sampling_default, allowed_values))  # noqa: E501

        self._ab_sampling_default = ab_sampling_default

    @property
    def ab_sample_size_default(self):
        """Gets the ab_sample_size_default of this PublicEmailTestingDetails.  # noqa: E501

        Version of the email that should be sent if there are too few recipients to conduct an AB test.  # noqa: E501

        :return: The ab_sample_size_default of this PublicEmailTestingDetails.  # noqa: E501
        :rtype: str
        """
        return self._ab_sample_size_default

    @ab_sample_size_default.setter
    def ab_sample_size_default(self, ab_sample_size_default):
        """Sets the ab_sample_size_default of this PublicEmailTestingDetails.

        Version of the email that should be sent if there are too few recipients to conduct an AB test.  # noqa: E501

        :param ab_sample_size_default: The ab_sample_size_default of this PublicEmailTestingDetails.  # noqa: E501
        :type ab_sample_size_default: str
        """
        allowed_values = ["master", "variant", "loser_variant", "mab_master", "mab_variant", "automated_master", "automated_variant", "automated_loser_variant"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and ab_sample_size_default not in allowed_values:  # noqa: E501
            raise ValueError("Invalid value for `ab_sample_size_default` ({0}), must be one of {1}".format(ab_sample_size_default, allowed_values))  # noqa: E501

        self._ab_sample_size_default = ab_sample_size_default

    @property
    def ab_status(self):
        """Gets the ab_status of this PublicEmailTestingDetails.  # noqa: E501

        Status of the AB test.  # noqa: E501

        :return: The ab_status of this PublicEmailTestingDetails.  # noqa: E501
        :rtype: str
        """
        return self._ab_status

    @ab_status.setter
    def ab_status(self, ab_status):
        """Sets the ab_status of this PublicEmailTestingDetails.

        Status of the AB test.  # noqa: E501

        :param ab_status: The ab_status of this PublicEmailTestingDetails.  # noqa: E501
        :type ab_status: str
        """
        allowed_values = ["master", "variant", "loser_variant", "mab_master", "mab_variant", "automated_master", "automated_variant", "automated_loser_variant"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and ab_status not in allowed_values:  # noqa: E501
            raise ValueError("Invalid value for `ab_status` ({0}), must be one of {1}".format(ab_status, allowed_values))  # noqa: E501

        self._ab_status = ab_status

    @property
    def ab_test_percentage(self):
        """Gets the ab_test_percentage of this PublicEmailTestingDetails.  # noqa: E501

        The size of your test group.  # noqa: E501

        :return: The ab_test_percentage of this PublicEmailTestingDetails.  # noqa: E501
        :rtype: int
        """
        return self._ab_test_percentage

    @ab_test_percentage.setter
    def ab_test_percentage(self, ab_test_percentage):
        """Sets the ab_test_percentage of this PublicEmailTestingDetails.

        The size of your test group.  # noqa: E501

        :param ab_test_percentage: The ab_test_percentage of this PublicEmailTestingDetails.  # noqa: E501
        :type ab_test_percentage: int
        """

        self._ab_test_percentage = ab_test_percentage

    @property
    def hours_to_wait(self):
        """Gets the hours_to_wait of this PublicEmailTestingDetails.  # noqa: E501

        Time limit on gathering test results. After this time is up, the winning version will be sent to the remaining contacts.  # noqa: E501

        :return: The hours_to_wait of this PublicEmailTestingDetails.  # noqa: E501
        :rtype: int
        """
        return self._hours_to_wait

    @hours_to_wait.setter
    def hours_to_wait(self, hours_to_wait):
        """Sets the hours_to_wait of this PublicEmailTestingDetails.

        Time limit on gathering test results. After this time is up, the winning version will be sent to the remaining contacts.  # noqa: E501

        :param hours_to_wait: The hours_to_wait of this PublicEmailTestingDetails.  # noqa: E501
        :type hours_to_wait: int
        """

        self._hours_to_wait = hours_to_wait

    @property
    def test_id(self):
        """Gets the test_id of this PublicEmailTestingDetails.  # noqa: E501

        The ID of the AB test.  # noqa: E501

        :return: The test_id of this PublicEmailTestingDetails.  # noqa: E501
        :rtype: str
        """
        return self._test_id

    @test_id.setter
    def test_id(self, test_id):
        """Sets the test_id of this PublicEmailTestingDetails.

        The ID of the AB test.  # noqa: E501

        :param test_id: The test_id of this PublicEmailTestingDetails.  # noqa: E501
        :type test_id: str
        """

        self._test_id = test_id

    @property
    def ab_success_metric(self):
        """Gets the ab_success_metric of this PublicEmailTestingDetails.  # noqa: E501

        Metric to determine the version that will be sent to the remaining contacts.  # noqa: E501

        :return: The ab_success_metric of this PublicEmailTestingDetails.  # noqa: E501
        :rtype: str
        """
        return self._ab_success_metric

    @ab_success_metric.setter
    def ab_success_metric(self, ab_success_metric):
        """Sets the ab_success_metric of this PublicEmailTestingDetails.

        Metric to determine the version that will be sent to the remaining contacts.  # noqa: E501

        :param ab_success_metric: The ab_success_metric of this PublicEmailTestingDetails.  # noqa: E501
        :type ab_success_metric: str
        """
        allowed_values = ["CLICKS_BY_OPENS", "CLICKS_BY_DELIVERED", "OPENS_BY_DELIVERED"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and ab_success_metric not in allowed_values:  # noqa: E501
            raise ValueError("Invalid value for `ab_success_metric` ({0}), must be one of {1}".format(ab_success_metric, allowed_values))  # noqa: E501

        self._ab_success_metric = ab_success_metric

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PublicEmailTestingDetails):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PublicEmailTestingDetails):
            return True

        return self.to_dict() != other.to_dict()



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from hubspot.communication_preferences.api.definition_api import DefinitionApi
from hubspot.communication_preferences.api.status_api import StatusApi



import hubspot.conversations.visitor_identification as api_client
from ...discovery_base import DiscoveryBase


class Discovery(DiscoveryBase):
    @property
    def generate_api(self) -> api_client.GenerateApi:
        return self._configure_api_client(api_client, "GenerateApi")



# coding: utf-8

"""
    Auth Oauth

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.oauth.configuration import Configuration


class AccessTokenInfoResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"hub_id": "int", "user_id": "int", "scopes": "list[str]", "token_type": "str", "user": "str", "hub_domain": "str", "app_id": "int", "expires_in": "int", "token": "str"}

    attribute_map = {
        "hub_id": "hub_id",
        "user_id": "user_id",
        "scopes": "scopes",
        "token_type": "token_type",
        "user": "user",
        "hub_domain": "hub_domain",
        "app_id": "app_id",
        "expires_in": "expires_in",
        "token": "token",
    }

    def __init__(self, hub_id=None, user_id=None, scopes=None, token_type=None, user=None, hub_domain=None, app_id=None, expires_in=None, token=None, local_vars_configuration=None):  # noqa: E501
        """AccessTokenInfoResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._hub_id = None
        self._user_id = None
        self._scopes = None
        self._token_type = None
        self._user = None
        self._hub_domain = None
        self._app_id = None
        self._expires_in = None
        self._token = None
        self.discriminator = None

        self.hub_id = hub_id
        self.user_id = user_id
        self.scopes = scopes
        self.token_type = token_type
        if user is not None:
            self.user = user
        if hub_domain is not None:
            self.hub_domain = hub_domain
        self.app_id = app_id
        self.expires_in = expires_in
        self.token = token

    @property
    def hub_id(self):
        """Gets the hub_id of this AccessTokenInfoResponse.  # noqa: E501

          # noqa: E501

        :return: The hub_id of this AccessTokenInfoResponse.  # noqa: E501
        :rtype: int
        """
        return self._hub_id

    @hub_id.setter
    def hub_id(self, hub_id):
        """Sets the hub_id of this AccessTokenInfoResponse.

          # noqa: E501

        :param hub_id: The hub_id of this AccessTokenInfoResponse.  # noqa: E501
        :type hub_id: int
        """
        if self.local_vars_configuration.client_side_validation and hub_id is None:  # noqa: E501
            raise ValueError("Invalid value for `hub_id`, must not be `None`")  # noqa: E501

        self._hub_id = hub_id

    @property
    def user_id(self):
        """Gets the user_id of this AccessTokenInfoResponse.  # noqa: E501

          # noqa: E501

        :return: The user_id of this AccessTokenInfoResponse.  # noqa: E501
        :rtype: int
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this AccessTokenInfoResponse.

          # noqa: E501

        :param user_id: The user_id of this AccessTokenInfoResponse.  # noqa: E501
        :type user_id: int
        """
        if self.local_vars_configuration.client_side_validation and user_id is None:  # noqa: E501
            raise ValueError("Invalid value for `user_id`, must not be `None`")  # noqa: E501

        self._user_id = user_id

    @property
    def scopes(self):
        """Gets the scopes of this AccessTokenInfoResponse.  # noqa: E501

          # noqa: E501

        :return: The scopes of this AccessTokenInfoResponse.  # noqa: E501
        :rtype: list[str]
        """
        return self._scopes

    @scopes.setter
    def scopes(self, scopes):
        """Sets the scopes of this AccessTokenInfoResponse.

          # noqa: E501

        :param scopes: The scopes of this AccessTokenInfoResponse.  # noqa: E501
        :type scopes: list[str]
        """
        if self.local_vars_configuration.client_side_validation and scopes is None:  # noqa: E501
            raise ValueError("Invalid value for `scopes`, must not be `None`")  # noqa: E501

        self._scopes = scopes

    @property
    def token_type(self):
        """Gets the token_type of this AccessTokenInfoResponse.  # noqa: E501

          # noqa: E501

        :return: The token_type of this AccessTokenInfoResponse.  # noqa: E501
        :rtype: str
        """
        return self._token_type

    @token_type.setter
    def token_type(self, token_type):
        """Sets the token_type of this AccessTokenInfoResponse.

          # noqa: E501

        :param token_type: The token_type of this AccessTokenInfoResponse.  # noqa: E501
        :type token_type: str
        """
        if self.local_vars_configuration.client_side_validation and token_type is None:  # noqa: E501
            raise ValueError("Invalid value for `token_type`, must not be `None`")  # noqa: E501

        self._token_type = token_type

    @property
    def user(self):
        """Gets the user of this AccessTokenInfoResponse.  # noqa: E501

          # noqa: E501

        :return: The user of this AccessTokenInfoResponse.  # noqa: E501
        :rtype: str
        """
        return self._user

    @user.setter
    def user(self, user):
        """Sets the user of this AccessTokenInfoResponse.

          # noqa: E501

        :param user: The user of this AccessTokenInfoResponse.  # noqa: E501
        :type user: str
        """

        self._user = user

    @property
    def hub_domain(self):
        """Gets the hub_domain of this AccessTokenInfoResponse.  # noqa: E501

          # noqa: E501

        :return: The hub_domain of this AccessTokenInfoResponse.  # noqa: E501
        :rtype: str
        """
        return self._hub_domain

    @hub_domain.setter
    def hub_domain(self, hub_domain):
        """Sets the hub_domain of this AccessTokenInfoResponse.

          # noqa: E501

        :param hub_domain: The hub_domain of this AccessTokenInfoResponse.  # noqa: E501
        :type hub_domain: str
        """

        self._hub_domain = hub_domain

    @property
    def app_id(self):
        """Gets the app_id of this AccessTokenInfoResponse.  # noqa: E501

          # noqa: E501

        :return: The app_id of this AccessTokenInfoResponse.  # noqa: E501
        :rtype: int
        """
        return self._app_id

    @app_id.setter
    def app_id(self, app_id):
        """Sets the app_id of this AccessTokenInfoResponse.

          # noqa: E501

        :param app_id: The app_id of this AccessTokenInfoResponse.  # noqa: E501
        :type app_id: int
        """
        if self.local_vars_configuration.client_side_validation and app_id is None:  # noqa: E501
            raise ValueError("Invalid value for `app_id`, must not be `None`")  # noqa: E501

        self._app_id = app_id

    @property
    def expires_in(self):
        """Gets the expires_in of this AccessTokenInfoResponse.  # noqa: E501

          # noqa: E501

        :return: The expires_in of this AccessTokenInfoResponse.  # noqa: E501
        :rtype: int
        """
        return self._expires_in

    @expires_in.setter
    def expires_in(self, expires_in):
        """Sets the expires_in of this AccessTokenInfoResponse.

          # noqa: E501

        :param expires_in: The expires_in of this AccessTokenInfoResponse.  # noqa: E501
        :type expires_in: int
        """
        if self.local_vars_configuration.client_side_validation and expires_in is None:  # noqa: E501
            raise ValueError("Invalid value for `expires_in`, must not be `None`")  # noqa: E501

        self._expires_in = expires_in

    @property
    def token(self):
        """Gets the token of this AccessTokenInfoResponse.  # noqa: E501

          # noqa: E501

        :return: The token of this AccessTokenInfoResponse.  # noqa: E501
        :rtype: str
        """
        return self._token

    @token.setter
    def token(self, token):
        """Sets the token of this AccessTokenInfoResponse.

          # noqa: E501

        :param token: The token of this AccessTokenInfoResponse.  # noqa: E501
        :type token: str
        """
        if self.local_vars_configuration.client_side_validation and token is None:  # noqa: E501
            raise ValueError("Invalid value for `token`, must not be `None`")  # noqa: E501

        self._token = token

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AccessTokenInfoResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AccessTokenInfoResponse):
            return True

        return self.to_dict() != other.to_dict()
